@@ -8,10 +8,6 @@ from __future__ import division
 from __future__ import print_function
 
 import numpy as np
-from keras.models import Sequential
-from keras.layers import Dense, Dropout
-from keras.regularizers import l2
-from keras.losses import mean_squared_error
 from sklearn.preprocessing import StandardScaler
 from sklearn.utils import check_array
 from sklearn.utils.validation import check_is_fitted
@@ -20,6 +16,19 @@ from ..utils.utility import check_parameter
 from ..utils.stat_models import pairwise_distances_no_broadcast
 
 from .base import BaseDetector
+from .base_dl import _get_tensorflow_version
+
+# if tensorflow 2, import from tf directly
+if _get_tensorflow_version() == 1:
+    from keras.models import Sequential
+    from keras.layers import Dense, Dropout
+    from keras.regularizers import l2
+    from keras.losses import mean_squared_error
+else:
+    from tensorflow.keras.models import Sequential
+    from tensorflow.keras.layers import Dense, Dropout
+    from tensorflow.keras.regularizers import l2
+    from tensorflow.keras.losses import mean_squared_error
 
 
 # noinspection PyUnresolvedReferences,PyPep8Naming,PyTypeChecker
@@ -78,7 +87,7 @@ class AutoEncoder(BaseDetector):
         - 1 = progress bar
         - 2 = one line per epoch.
 
-        For verbosity >= 1, model summary may be printed.
+        For verbose >= 1, model summary may be printed.
 
     random_state : random_state: int, RandomState instance or None, optional
         (default=None)
