@@ -279,6 +279,7 @@ def get_label_n(y, y_pred, n=None):
 
     return y_pred
 
+
 def get_intersection(lst1, lst2):
     """get the overlapping between two lists
 
@@ -321,6 +322,7 @@ def get_list_diff(li1, li2):
 
     return (list(set(li1) - set(li2)))
 
+
 def get_diff_elements(li1, li2):
     """get the elements in li1 but not li2, and vice versa
 
@@ -344,6 +346,7 @@ def get_diff_elements(li1, li2):
 
     return (list(set(li1) - set(li2)) + list(set(li2) - set(li1)))
 
+
 def argmaxn(value_list, n, order='desc'):
     """Return the index of top n elements in the list
     if order is set to 'desc', otherwise return the index of n smallest ones.
@@ -439,28 +442,28 @@ def _get_sklearn_version():  # pragma: no cover
 
     sklearn_version = str(sklearn.__version__)
     if int(sklearn_version.split(".")[1]) < 19 or int(
-            sklearn_version.split(".")[1]) > 23:
+            sklearn_version.split(".")[1]) > 24:
         raise ValueError("Sklearn version error")
 
     return int(sklearn_version.split(".")[1])
 
 
-def _sklearn_version_21():  # pragma: no cover
-    """ Utility function to decide the version of sklearn
-    In sklearn 21.0, LOF is changed. Specifically, _decision_function
-    is replaced by _score_samples
-
-    Returns
-    -------
-    sklearn_21_flag : bool
-        True if sklearn.__version__ is newer than 0.21.0
-
-    """
-    sklearn_version = str(sklearn.__version__)
-    if int(sklearn_version.split(".")[1]) > 20:
-        return True
-    else:
-        return False
+# def _sklearn_version_21():  # pragma: no cover
+#     """ Utility function to decide the version of sklearn
+#     In sklearn 21.0, LOF is changed. Specifically, _decision_function
+#     is replaced by _score_samples
+#
+#     Returns
+#     -------
+#     sklearn_21_flag : bool
+#         True if sklearn.__version__ is newer than 0.21.0
+#
+#     """
+#     sklearn_version = str(sklearn.__version__)
+#     if int(sklearn_version.split(".")[1]) > 20:
+#         return True
+#     else:
+#         return False
 
 
 def generate_bagging_indices(random_state, bootstrap_features, n_features,
